@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130329';
+our $VERSION = '0.20130430';
 
-# Table last modified: 2013-03-29
+# Table last modified: 2013-04-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:[12]\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|4[0-46-9]|3[013-9])|5(?:[12458]\d|3[0-35-9]|7[02-9]|0[1-35689]|6[013-9])|7(?:11|67|2[015]|9[25-7]|0[35-7])))',
+    '060' => '(?:8(?:6(?:[12]\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|4[0-46-9]|3[013-9])|5(?:[2458]\d|1[1-9]|3[0-35-9]|7[02-9]|0[1-35689]|6[013-9])|7(?:11|67|2[015]|9[25-7]|0[35-7])))',
     '061' => '(?:(?:1(?:49[236-8]|19[2356]|39[2356])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:6(?:0[1-36-8]|1[12]|4[15])|5(?:58|0[17]|[18][05])))',
@@ -103,19 +103,19 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[0168]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|4[158]|2[1245]|3[138]|0[237]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|5[018]|0[2358]|4[0149]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|4[158]|2[1245]|3[138]|0[237]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[035])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-25-8]|1[14-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|2[014589]|5[167]|7[27]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-25-8]|1[14-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|7[027]|2[014589]|5[167]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[015-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|0[357]|8[0134689]|7[0-37-9]|5[0158]|2[0235689]|4[15]|3[013489]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
+    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
@@ -123,9 +123,9 @@ our %ZIP_TABLE = (
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[03568])|60[12]))',
     '121' => '(?:8(?:5(?:33|40|1[015]|0[245]|2[0-4]|8[58]|5[05])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
     '123' => '(?:85(?:40|8[58]|1[147]|0[135689]))',
-    '124' => '(?:8(?:5(?:77|6[06]|1[018]|3[3589]|0[1-39]|8[58]|5[05]|2[024])|070))',
-    '125' => '(?:8(?:5(?:55|88|1[1-57]|0[3-8]|2[026])|601))',
-    '130' => '(?:8(?:5(?:6[5-7]|7[057]|8[0348]|3[013-589]|4[358]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|0[1-589]|7[17]|3[67]|5[05]|6[068]|1[15]|4[024])|7(?:[12]0|0[16])))',
+    '124' => '(?:85(?:60|77|2[04]|3[3589]|0[1-39]|8[58]|5[05]|1[01]))',
+    '125' => '(?:8(?:5(?:55|1[1-57]|0[3-8]|8[58]|2[026])|601))',
+    '130' => '(?:8(?:5(?:7[057]|8[0348]|3[013-589]|4[358]|6[15-7]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|0[1-589]|7[17]|3[67]|5[05]|6[068]|1[15]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|634|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
@@ -141,7 +141,7 @@ our %ZIP_TABLE = (
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
     '150' => '(?:8(?:5(?:45|8[5-7]|2[25]|6[379]|5[05]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
-    '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:00|7[1-7])|40[14]))',
+    '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|6[05-8]|2[0135]|3[0-369]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
@@ -153,7 +153,7 @@ our %ZIP_TABLE = (
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[13])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|6[156]|5[35])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[67]7|30|2[25]|8[58]|5[05]|0[13-5]|1[12]|4[01])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[248])|7(?:01|25)))',
+    '164' => '(?:8(?:5(?:[67]7|30|41|2[25]|8[58]|5[05]|0[13-5]|1[12])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[24])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
@@ -180,7 +180,7 @@ our %ZIP_TABLE = (
     '189' => '(?:85(?:[01]1|85|5[05]|2[01]))',
     '190' => '(?:(?:8(?:5(?:3[015-79]|5[013-578]|6[0-256]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|55|0[1-35-79]|1[0-2])|6(?:60|86)))',
-    '192' => '(?:(?:8(?:5(?:77|85|1[0-2568]|2[025]|6[28]|5[1368]|3[235-8]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-8])))',
+    '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
     '194' => '(?:(?:8(?:5(?:77|1[015]|4[03]|0[23578]|8[0568]|5[0158]|2[07]|6[067]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
     '195' => '(?:85(?:85|5[05]))',
@@ -353,7 +353,7 @@ our %ZIP_TABLE = (
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|19[235]|29[2-4]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|6(?:01|16))|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[01457]|9[2-578])|39[2358]|29[28])|1(?:[16]92|[24]98|393)|0(?:19[2356]|292)))',
-    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|0[1-8]|7[0235-7]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:22|55|0[158]|3[0359]|6[068]|8[68]|4[08]|1[0-24])|79[4-8]))',
+    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|0[1-8]|7[0235-7]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|6[068]|8[68]|4[08]|1[0-24])|79[4-8]))',
     '381' => '(?:(?:8(?:5(?:[67][07]|3[09]|0[138]|4[58]|2[05]|1[0-2]|8[08]|5[68])|6(?:02|86)|79[13])|0(?:29[23578]|19[23]|49[78])|22(?:8[1-35-8]|9[258])|4(?:19[23]|393)))',
     '382' => '(?:8(?:5(?:33|55|0[128]|8[578]|1[01])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|0[156]|1[15])|6(?:14|86)))',
@@ -419,7 +419,7 @@ our %ZIP_TABLE = (
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|5[058]|3[35]|0[1-8]|8[58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
-    '448' => '(?:8(?:6(?:10|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:31|50|2[35]|0[16])|731))',
+    '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:50|4[23]|3[14]|2[35]|0[16])|731))',
     '449' => '(?:029[2-4])',
     '450' => '(?:(?:8(?:5(?:40|3[0238]|2[013]|1[05]|7[57]|6[157]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[1458]|5[01])|7(?:11|30|65))|6133))',
     '451' => '(?:8(?:5(?:[14]1|85|[56][0158]|2[0-25]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
@@ -441,8 +441,8 @@ our %ZIP_TABLE = (
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[039])))',
     '468' => '(?:8(?:5(?:2[02]|1[0-4]|8[58]|0[1-7]|3[1-467])|626))',
     '469' => '(?:879[3467])',
-    '470' => '(?:(?:0(?:1(?:88|9[24-68])|29[2-7]|39[2-6]|49[2356]|592)|2(?:19[235-7]|29[26-8]|39[2-48]|49[23])|1(?:19[2-68]|29[2-6])|3(?:29[56]|495)))',
-    '471' => '(?:8(?:5(?:7[1-4]|6[056]|3[0-25-7]|0[1-36-8]|8[58]|5[05]|1[0235]|2[1257])|60[1-39]))',
+    '470' => '(?:(?:0(?:1(?:88|9[24-68])|29[2-7]|39[2-6]|49[2356]|592)|2(?:19[1-35-7]|29[26-8]|39[2-48]|49[23])|1(?:19[2-68]|29[2-6])|3(?:29[56]|495)))',
+    '471' => '(?:8(?:5(?:7[1-4]|6[056]|3[0-25-7]|0[1-36-8]|1[0235-8]|8[58]|5[05]|2[1257])|60[1-39]))',
     '472' => '(?:8(?:6(?:[68]6|39)|5[58]5))',
     '473' => '(?:85(?:01|33|1[12]))',
     '474' => '(?:8(?:5(?:22|35|43|8[01458]|5[0578]|1[01]|0[1-35])|6(?:[05]1|42|66|8[68]|1[01])|7(?:10|66|77|0[17])))',
@@ -536,7 +536,7 @@ our %ZIP_TABLE = (
     '565' => '(?:85(?:11|40|65))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
     '567' => '(?:8(?:5(?:[34]0|[56]7|78|85|1[015]|2[0135]|0[125])|6(?:51|80)))',
-    '569' => '(?:(?:8(?:5(?:33|49|77|0[135]|2[02]|[58][58]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
+    '569' => '(?:(?:8(?:5(?:33|49|77|0[135]|5[158]|2[02]|8[58]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[125-7]|[58][58]|1[15])|6(?:[68]6|34|77)))',
     '571' => '(?:8(?:5(?:[45]5|67|71|8[05]|0[2-47])|6(?:33|86)))',
     '572' => '(?:85(?:40|67|8[01589]|2[28]|3[013]|7[02]|5[0158]|0[1578]|1[01]))',
@@ -565,7 +565,7 @@ our %ZIP_TABLE = (
     '597' => '(?:8(?:5(?:22|43|55|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
-    '600' => '(?:8(?:5(?:4[04]|3[03]|1[019]|5[058]|8[1568]|7[07]|6[067]|0[1-35])|6(?:77|5[12]|8[68]|6[56])|7(?:11|87)))',
+    '600' => '(?:8(?:5(?:25|4[04]|3[03]|1[019]|5[058]|8[1568]|7[07]|6[067]|0[1-35])|6(?:77|5[12]|8[68]|6[56])|7(?:11|87)))',
     '601' => '(?:(?:8(?:5(?:01|20|42|3[03]|8[58]|5[05]|1[01])|680)|0(?:292|797)|1(?:192|495)))',
     '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|611))',
     '603' => '(?:85(?:11|22|55|77|88))',
@@ -764,7 +764,7 @@ our %ZIP_TABLE = (
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
     '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|12|79)))',
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
-    '808' => '(?:(?:8(?:5(?:02|1[045]|5[058]|8[58])|606)|0196))',
+    '808' => '(?:(?:8(?:5(?:1[045]|0[25]|5[058]|8[58])|606)|0196))',
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|5[135-8]|2[0-578]|0[1-46-9]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|8[35689]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|49[256]|19[23]|39[28]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|1(?:39[2-57]|29[28])|0(?:19[2356]|295)|5192))',
@@ -786,7 +786,7 @@ our %ZIP_TABLE = (
     '827' => '(?:8501)',
     '828' => '(?:8501)',
     '829' => '(?:039[23])',
-    '830' => '(?:(?:8(?:5(?:67|0[135]|3[03]|4[013]|1[0-25]|7[07]|8[358]|5[58]|2[0-2])|6(?:77|6[6-8]|0[1-36]|1[12]|2[29]|8[68]|3[01]))|1(?:19[2356]|29[258])|65(?:28|87)|0[12]92))',
+    '830' => '(?:(?:8(?:5(?:67|0[135]|3[03]|4[013]|1[0-25]|7[07]|[58][58]|2[0-2])|6(?:77|6[6-8]|0[1-36]|1[12]|2[29]|8[68]|3[01]))|1(?:19[2356]|29[258])|65(?:28|87)|0[12]92))',
     '831' => '(?:8(?:6(?:01|86)|501))',
     '832' => '(?:8(?:555|601))',
     '833' => '(?:8601)',
@@ -795,7 +795,7 @@ our %ZIP_TABLE = (
     '836' => '(?:8(?:5(?:77|3[134]|0[25]|1[02]|6[67]|8[58]|5[56])|6(?:10|66|8[06])))',
     '837' => '(?:8501)',
     '838' => '(?:(?:8(?:6(?:[68]6|77|0[12])|5(?:85|1[25]))|1(?:39[78]|79[23]|[56]92)|0(?:19[378]|298)))',
-    '839' => '(?:(?:1(?:39[3-6]|49[378]|298)|85(?:40|0[1258])|029[235]))',
+    '839' => '(?:(?:1(?:39[3-6]|49[378]|298)|85(?:40|0[12568])|029[235]))',
     '840' => '(?:(?:8(?:5(?:[246]0|11|5[0-258]|8[058]|0[12]|7[01])|6(?:[01]1|27|66|8[689]))|2(?:19[2357]|295)|0(?:292|598)|1192))',
     '841' => '(?:8(?:6(?:11|86|0[12])|5(?:[01]1|85)))',
     '842' => '(?:(?:8(?:5(?:85|0[12])|601)|0(?:19[2357]|29[23])))',
@@ -856,7 +856,7 @@ our %ZIP_TABLE = (
     '897' => '(?:(?:039[23]|8501))',
     '898' => '(?:8501)',
     '899' => '(?:(?:5(?:29[2-4]|69[348]|19[23]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|(?:3[14]|7[146]|8[16])92|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|0(?:29[23578]|492)|1(?:395|498|696)))',
-    '900' => '(?:8(?:5(?:4[03-57]|5\d|2[02457]|0[13-57]|6[07]|3[013-5]|7[01578]|8[01568]|1[0-467])|6(?:10|66|78|5[0146]|0[1-59]|8[68])|7(?:[01]1|35|9[4-7])))',
+    '900' => '(?:8(?:5(?:5\d|2[02457]|0[13-57]|4[03-578]|6[07]|3[013-5]|7[01578]|8[01568]|1[0-467])|6(?:10|66|78|5[0146]|0[1-59]|8[68])|7(?:[01]1|35|9[4-7])))',
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|0[1268]|1[0-25]|5[0-35-9]|3[014]|2[0156])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|29[2-5]|19[2-4]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
     '902' => '(?:85(?:21|8[58]|5[05]|1[0-2]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
@@ -913,7 +913,7 @@ our %ZIP_TABLE = (
     '956' => '(?:(?:860[1-3]|0192))',
     '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01))|0(?:19[2367]|293)))',
     '958' => '(?:(?:8(?:5(?:01|33|85|5[58])|6(?:01|86))|0292))',
-    '959' => '(?:(?:0(?:29[2-6]|19[2-5]|59[235]|39[23]|492)|1(?:29[23568]|39[2357]|69[235]|79[457])|2(?:39[357]|09[23]|292|693|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
+    '959' => '(?:(?:0(?:29[2-6]|19[2-4]|59[235]|39[23]|492)|1(?:29[2368]|39[2357]|69[235]|79[457])|2(?:39[357]|09[23]|292|693|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
     '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|1[1258]|8[014589]|5[058]|6[067]|3[0146]|2[0-4])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
